
import FWCore.ParameterSet.Config as cms

AlignmentTrackSelector = cms.EDFilter("AlignmentTrackSelectorModule",
    src = cms.InputTag("generalTracks"),
    filter = cms.bool(False),

    # Settings for the base TrackSelector 	
    # FIXME this should get its own PSet
    applyBasicCuts = cms.bool(True),
    ptMin = cms.double(0.0),
    ptMax = cms.double(999.0),
    pMin = cms.double(0.0),
    pMax = cms.double(9999.0),
    etaMin = cms.double(-2.6),
    etaMax = cms.double(2.6),
    phiMax = cms.double(3.1416),
    phiMin = cms.double(-3.1416),
    chi2nMax = cms.double(999999.0),

    nHitMin = cms.double(0.0),
    nHitMax = cms.double(999.0),
    nHitMin2D = cms.uint32(0),
    countStereoHitAs2D = cms.bool(True),
    minHitsPerSubDet = cms.PSet(
        inTEC = cms.int32(0),
        inTOB = cms.int32(0),
        inFPIX = cms.int32(0),
        inTID = cms.int32(0),
        inBPIX = cms.int32(0),
        inTIB = cms.int32(0)
    ),
    seedOnlyFrom = cms.int32(0),

    applyMultiplicityFilter = cms.bool(False),
    minMultiplicity = cms.int32(1),
    maxMultiplicity = cms.int32(999999),
    multiplicityOnInput = cms.bool(False),

    applyNHighestPt = cms.bool(False),
    nHighestPt = cms.int32(2),

    rphirecHits = cms.InputTag("siStripMatchedRecHits","rphiRecHit"),
    matchedrecHits = cms.InputTag("siStripMatchedRecHits","matchedRecHit"),
    applyIsolationCut = cms.bool(False),
    minHitIsolation = cms.double(0.01),
    applyChargeCheck = cms.bool(False),
    minHitChargeStrip = cms.double(20.0),

    GlobalSelector = cms.PSet(
        #for isolation Tests
        applyIsolationtest = cms.bool(False),
        muonSource = cms.InputTag("muons"),
        minIsolatedCount = cms.int32(0),
        jetIsoSource = cms.InputTag("kt6CaloJets"),
        minGlobalMuonCount = cms.int32(1),
        minJetDeltaR = cms.double(0.2),
        maxJetCount = cms.int32(3),
        #for global muon finding
        applyGlobalMuonFilter = cms.bool(False),
        minJetPt = cms.double(40.0), ##GeV

        jetCountSource = cms.InputTag("kt6CaloJets"),
        maxJetPt = cms.double(40.0), ##GeV

        #for Jet Count
        applyJetCountFilter = cms.bool(False),
        maxTrackDeltaR = cms.double(0.001)
    ),
    # Settings for the two Body Decay TrackSelector
    TwoBodyDecaySelector = cms.PSet(
        applyMassrangeFilter = cms.bool(False),
        daughterMass = cms.double(0.105), ##GeV

        useUnsignedCharge = cms.bool(True),
        missingETSource = cms.InputTag("met"),
        maxXMass = cms.double(15000.0), ##GeV

        charge = cms.int32(0),
        acoplanarDistance = cms.double(1.0), ##radian

        minXMass = cms.double(0.0), ##GeV

        applyChargeFilter = cms.bool(False),
        applyAcoplanarityFilter = cms.bool(False),
        applyMissingETFilter = cms.bool(False)
    )
)


